@@ -9,33 +9,33 @@
 Surrogate = R6Class("Surrogate",
   public = list(
 
-    #' @field model (model)\cr
-    #'   Arbitrary model object depending on the subclass.
-    model = NULL,
+    #' @field learner (learner)\cr
+    #'   Arbitrary learner object depending on the subclass.
+    learner = NULL,
 
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     #'
-    #' @param model (model)\cr
-    #'   Arbitrary model object depending on the subclass.
+    #' @param learner (learner)\cr
+    #'   Arbitrary learner object depending on the subclass.
     #' @template param_archive_surrogate
-    #' @template param_x_cols_surrogate
-    #' @template param_y_cols_surrogate
+    #' @template param_cols_x_surrogate
+    #' @template param_cols_y_surrogate
     #' @param param_set ([paradox::ParamSet])\cr
     #'   Parameter space description depending on the subclass.
-    initialize = function(model, archive, x_cols, y_cols, param_set) {
+    initialize = function(learner, archive, cols_x, cols_y, param_set) {
       # most assertions are done in subclasses
-      self$model = model
+      self$learner = learner
       private$.archive = assert_r6(archive, classes = "Archive", null.ok = TRUE)
-      private$.x_cols = assert_character(x_cols, min.len = 1L, null.ok = TRUE)
-      private$.y_cols = y_cols = assert_character(y_cols, min.len = 1L, null.ok = TRUE)
+      private$.cols_x = assert_character(cols_x, min.len = 1L, null.ok = TRUE)
+      private$.cols_y = cols_y = assert_character(cols_y, min.len = 1L, null.ok = TRUE)
       assert_r6(param_set, classes = "ParamSet")
       assert_r6(param_set$params$catch_errors, classes = "ParamLgl")
       private$.param_set = param_set
     },
 
     #' @description
-    #' Train model with new data.
+    #' Train learner with new data.
     #' Subclasses must implement `$private.update()`.
     #'
     #' @return `NULL`.
@@ -109,31 +109,32 @@ Surrogate = R6Class("Surrogate",
       stop("Abstract.")
     },
 
-    #' @template field_x_cols_surrogate
-    x_cols = function(rhs) {
+    #' @template field_cols_x_surrogate
+    cols_x = function(rhs) {
       if (missing(rhs)) {
-        if (is.null(private$.x_cols)) self$archive$cols_x else private$.x_cols
+        if (is.null(private$.cols_x)) self$archive$cols_x else private$.cols_x
       } else {
-        private$.x_cols = assert_character(rhs, min.len = 1L)
+        private$.cols_x = assert_character(rhs, min.len = 1L)
       }
     },
 
-    #' @template field_y_cols_surrogate
-    y_cols = function(rhs) {
+    #' @template field_cols_y_surrogate
+    cols_y = function(rhs) {
       if (missing(rhs)) {
-        if (is.null(private$.y_cols)) self$archive$cols_y else private$.y_cols
+        if (is.null(private$.cols_y)) self$archive$cols_y else private$.cols_y
       } else {
-        private$.y_cols = assert_character(rhs, len = self$n_learner)
+        private$.cols_y = assert_character(rhs, len = self$n_learner)
       }
     },
 
     #' @field insample_perf (`numeric()`)\cr
     #'   Surrogate model's current insample performance.
     insample_perf = function(rhs) {
-      if (!missing(rhs)) {
+      if (missing(rhs)) {
+        private$.insample_perf %??% NaN
+      } else {
         stop("$insample_perf is read-only.")
       }
-      private$.insample_perf %??% NaN
     },
 
     #' @field param_set ([paradox::ParamSet])\cr
@@ -141,8 +142,9 @@ Surrogate = R6Class("Surrogate",
     param_set = function(rhs) {
       if (!missing(rhs) && !identical(rhs, private$.param_set)) {
         stop("$param_set is read-only.")
+      } else {
+        private$.param_set
       }
-      private$.param_set
     },
 
     #' @template field_assert_insample_perf_surrogate
@@ -182,7 +184,7 @@ Surrogate = R6Class("Surrogate",
       if (missing(rhs)) {
         stop("Abstract.")
       } else {
-        stop("$predict_type is read-only. To change it, modify $predict_type of the model directly.")
+        stop("$predict_type is read-only. To change it, modify $predict_type of the learner directly.")
       }
     }
   ),
@@ -191,9 +193,9 @@ Surrogate = R6Class("Surrogate",
 
     .archive = NULL,
 
-    .x_cols = NULL,
+    .cols_x = NULL,
 
-    .y_cols = NULL,
+    .cols_y = NULL,
 
     .insample_perf = NULL,
 
