@@ -16,7 +16,7 @@
 #'   Size of the initial design.
 #'   If `NULL` and the [bbotk::Archive] contains no evaluations, \code{4 * d} is used with \code{d} being the
 #'   dimensionality of the search space.
-#'   Points are drawn uniformly at random.
+#'   Points are generated via a Sobol sequence.
 #' @param surrogate ([Surrogate])\cr
 #'   [Surrogate] to be used as a surrogate.
 #'   Typically a [SurrogateLearner].
@@ -95,7 +95,7 @@
 #'     terminator = trm("evals", n_evals = 5))
 #'
 #'   surrogate = default_surrogate(instance, n_learner = 2)
-#'   surrogate$y_cols = c("y", "time")
+#'   surrogate$cols_y = c("y", "time")
 #'
 #'   optimizer = opt("mbo",
 #'     loop_function = bayesopt_ego,
@@ -108,39 +108,37 @@
 #' }
 bayesopt_ego = function(
     instance,
-    init_design_size = NULL,
     surrogate,
     acq_function,
     acq_optimizer,
+    init_design_size = NULL,
     random_interleave_iter = 0L
   ) {
 
-  # assertions and defaults
+  # assertions
   assert_r6(instance, "OptimInstanceSingleCrit")
-  assert_int(init_design_size, lower = 1L, null.ok = TRUE)
   assert_r6(surrogate, classes = "Surrogate")  # cannot be SurrogateLearner due to EIPS
   assert_r6(acq_function, classes = "AcqFunction")
   assert_r6(acq_optimizer, classes = "AcqOptimizer")
+  assert_int(init_design_size, lower = 1L, null.ok = TRUE)
   assert_int(random_interleave_iter, lower = 0L)
 
-  archive = instance$archive
-  domain = instance$search_space
-  d = domain$length
-  if (is.null(init_design_size) && instance$archive$n_evals == 0L) init_design_size = 4L * d
+  # initial design
+  search_space = instance$search_space
+  if (is.null(init_design_size) && instance$archive$n_evals == 0L) {
+    init_design_size = 4L * search_space$length
+  }
+  if (!is.null(init_design_size) && instance$archive$n_evals == 0L) {
+    design = generate_design_sobol(search_space, n = init_design_size)$data
+    instance$eval_batch(design)
+  }
 
-  surrogate$archive = archive
+  # completing initialization
+  surrogate$archive = instance$archive
   acq_function$surrogate = surrogate
   acq_optimizer$acq_function = acq_function
 
-  # initial design
-  if (isTRUE(init_design_size > 0L)) {
-    design = generate_design_random(domain, n = init_design_size)$data
-    instance$eval_batch(design)
-  } else {
-    init_design_size = instance$archive$n_evals
-  }
-
-  # loop
+  # actual loop
   repeat {
     xdt = tryCatch({
       # random interleaving is handled here
@@ -153,7 +151,7 @@ bayesopt_ego = function(
     }, mbo_error = function(mbo_error_condition) {
       lg$info(paste0(class(mbo_error_condition), collapse = " / "))
       lg$info("Proposing a randomly sampled point")
-      SamplerUnif$new(domain)$sample(1L)$data
+      generate_design_random(search_space, n = 1L)$data
     })
 
     instance$eval_batch(xdt)
